local mod = RW:Boss("Sindragosa", "Icecrown Citadel", "Frostwing Hall")
local L

mod.BossIcon = [[Interface\Icons\achievement_boss_sindragosa]]

------------------------------------
-- Variables

local tEnrage

-- phases
local tLanding, tFlying, wFlying, wLanding, wP3

-- Blistering
local wBlister, tBlisterCD, tBlisterCast

-- Beacon
local tBeaconCD, mBeacon, wBeacon, iBeacon

-- Unchained Magic
local wUnchained, wUnchainedStacks

-- Chilled to the Bone
local wChilledStacks

-- Mystic Buffet
local tBuffetCD, tBuffetDur, wBuffet

-----------------------------------
-- Init

function mod:OnRegister()
	L = mod:RegisterLocale("enUS")
	if L then
		L.info = "Experimental mod still, timers and warnings may be invalid or off."
		
		L.YellPull = "You are fools to have come to this place. The icy winds of Northrend will consume your souls!"
		
		L.air_phase = "Your incursion ends here! None shall survive!"
		L.phase3 = "Now, feel my master's limitless power and despair!"
		
		L.landing = "Ground Phase"
		L.landing_warning = "Landing in 5s!"
		L.flying = "Air Phase"
		L.P3 = "Phase 3 Started"
		
		L.landing_opt = "Timer for when she lands"
		L.landing_warning_opt = "Warning for when she is about to land (5s)"
		L.flying_opt = "Timer for when she takes off"
		L.flying_warning_opt = "Warning for when she takes off"
		L.P3_opt = "Warning when Phase 3 starts"
		
		L.phase_group = "Phases"
		
		L.unchained_stacks = "Instability x %d!"
		L.unchained_stacks_opt = "Warning for high Instability stacks"
		
		L.chilled_stacks = "Chilled x %d"
		L.chilled_stacks_opt = "Warning for high count of Chilled stacks"
		
		L.buffet_stacks = "Buffet x %d"
		L.buffet_stacks_opt = "Warning for high count of Mystic Buffet"
	end
	L = mod:GetLocale()
	mod.L = L
	
	mod:SetTrigger(L.YellPull, 36853)
	mod:SetWin()
	mod:SetDelay(20)
	
	tEnrage					= self:BerserkTimer(600)
	
	tLanding				= self:CustomTimer(45, L.landing, L.landing_opt, [[Interface\Vehicles\UI-VEHICLES-BUTTON-PITCHDOWN-UP]], L.phase_group)
	tFlying					= self:CustomTimer(65, L.flying, L.flying_opt, [[Interface\Vehicles\UI-Vehicles-Button-Pitch-Up]], L.phase_group)
	wFlying					= self:CustomWarning(L.flying, L.flying_warning_opt, [[Interface\Vehicles\UI-VEHICLES-BUTTON-PITCHDOWN-UP]], L.phase_group)
	wLanding				= self:CustomWarning(L.landing_warning, L.landing_warning_opt, [[Interface\Vehicles\UI-Vehicles-Button-Pitch-Up]], L.phase_group)
	wP3						= self:CustomWarning(L.P3, L.P3_opt, [[Interface\Vehicles\UI-Vehicles-Button-Pitch-Up]], L.phase_group)
	
	-- Blister
	tBlisterCast			= self:CastTimer(70123)
	tBlisterCD				= self:CDTimer(40, 70123)	
	wBlister				= self:RunawayWarning(70123, nil, nil, nil, nil, "RW: ComeCloser")
	
	-- Beacon
	tBeaconCD				= self:CDTimer(16, 70126)
	mBeacon					= self:TargetMessage(70126)
	wBeacon					= self:RunawayWarning(70126)
	iBeacon					= self:Icon("SKULL", 70126, false, 15, "CROSS", "SQUARE", "TRIANGLE", "DIAMOND")
	
	-- Unchained magic
	wUnchained				= self:InformWarning(69762)
	wUnchainedStacks		= self:CustomWarning(L.unchained_stacks, L.unchained_stacks_opt, 69762)
	
	-- Chilled to the Bone
	wChilledStacks			= self:CustomWarning(L.chilled_stacks, L.chilled_stacks_opt, 70106)
	
	-- Mystic Buffet
	tBuffetCD				= self:CDTimer(6, 70128)
	tBuffetDur				= self:DurStackTimer(8, 70128)
	wBuffet					= self:CustomWarning(L.buffet_stacks, L.buffet_stacks_opt, 70128)
end

-----------------------------------------
-- Locals
local phase
local unchainedSpam
local chilledSpam
local buffetSpamm

-----------------------------------------
-- Start

function mod:OnEngage(trigger)
	self:Track("Pull", 70117)
	self:Track("Blister", 70123, 71047, 71048, 71049)
	self:Track("Beacon", 70126)
	self:Track("Unchained", 69762)
	self:Track("Instability", 69766)
	self:Track("Chilled", 70106)
	self:Track("Buffet", 70127, 70128, 72528, 72529, 72530) -- First is the debuff that gets applied to the player
	
	self:YellTrack("AirPhase", L.air_phase)
	self:YellTrack("P3", L.phase3)
	
	tFlying:Start(62)
	tBlisterCD:Start(45)
	
	phase = 1
	unchainedSpam = 0
	chilledSpam = 0
	buffetSpamm = 0
	
	tEnrage:Start()
end

function mod:Pull(event, args)
	if event == "SPELL_CAST_SUCCESS" or event == "SPELL_CAST_START" then
		wBlister:Show()
		
		if phase == 3 then
			tBlisterCD:Start(95)
		end
	end
end

function mod:Blister(event, args)
	if event == "SPELL_CAST_START" then
		tBlisterCast:Start()
	end
end

function mod:Beacon(event, args)
	if event == "SPELL_AURA_APPLIED" then
		if phase == 3 then
			mBeacon:Show(args.dName)
			tBeaconCD:Start()
		else
			mBeacon:AddDelayTarget(args.dName)
			mBeacon:DelayedShow(0.2)
		end
		if args:IsPlayer() then
			wBeacon:Show()
		end
		iBeacon:Show(args.dName)
	
	elseif event == "SPELL_AURA_REMOVED" then
		iBeacon:Hide(args.dName)
	end
end

function mod:Unchained(event, args)
	if event == "SPELL_AURA_APPLIED" then
		if args:IsPlayer() then
			wUnchained:Show()
		end
	end
end

function mod:Instability(event, args)
	if event == "SPELL_AURA_APPLIED_DOSE" then
		if args:IsPlayer() then
			if GetTime() - unchainedSpam > 5 then
				if phase == 1 and (args.amount or 1) >= 8 then
					wUnchainedStacks:Show(args.amount or 9)
					unchainedSpam = GetTime()
					
				elseif phase == 3 and (args.amount or 1) >= 4 then
					wUnchainedStacks:Show(args.amount or 5)
					unchainedSpam = GetTime()
				end
			end
		end
	end
end

function mod:Chilled(event, args)
	if event == "SPELL_AURA_APPLIED_DOSE" then
		if args:IsPlayer() then
			if GetTime() - chilledSpam > 5 then
				if phase == 1 and (args.amount or 1) >= 8 then
					wChilledStacks:Show(args.amount or 8)
					chilledSpam = GetTime()
					
				elseif phase == 3 and (args.amount or 1) >= 4 then
					wChilledStacks:Show(args.amount or 4)
					chilledSpam = GetTime()
				end
			end
		end
	end
end

function mod:Buffet(event, args)
	if event == "SPELL_AURA_APPLIED_DOSE" or event == "SPELL_AURA_APPLIED" then
		if args:IsPlayer() then
			if (args.amount or 1) == 4 then
				wBuffet:Show(args.amount or 1)
			end
			tBuffetDur:Start(nil, args.amount or 1)
		end
		if GetTime() - buffetSpamm > 1 then
			tBuffetCD:Start()
			buffetSpamm = GetTime()
		end
	end
end

function mod:AirPhase(event, msg, name)
	tLanding:Start()
	tFlying:Schedule(45)
	tBlisterCD:Schedule(45)
	wFlying:Show()
	wLanding:Schedule(35)
end

function mod:P3(event, msg, name)
	phase = 3
	tBlisterCD:Start()
	tFlying:Stop()
	wP3:Show()
end